Table of Contents — Breezy 3.0.2dev documentation

Table of Contents (3.0.2dev)

## Core documentation

What's New in Breezy 3.0? what's new in this release User Guide how to use the command line client Tutorials brief introductions Quick Reference for your wall | Release Notes a detailed log of changes Upgrade Guide moving to Breezy 3.x User Reference all the gory details System Admin Guide security, backups, etc.

## Related links

Desktop Guide how to use our GUI applications FAQ frequently asked questions Glossary help with terminology | Developer Docs improving and extending brz Migration Docs for refugees of other tools Plugins Guide help on popular plugins